import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Form, Row, Col, Select, Button, Input } from 'antd'
import './index.scss'


class UniqueForm extends Component {
  static propTpyes = {
    dict: PropTypes.object,       // 字典项
    columnChange: PropTypes.func  // 修改函数
  }

  state = {}

  handleConfirm = () => {
    // 表单提交时检查输入值是否正确
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        this.props.columnChange(values)
        this.props.form.setFieldsValue({
          label: '',
          field: ''
        })
      }
    })
  }

  render() {
    const { dict } = this.props
    const { getFieldDecorator } = this.props.form
    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      }
    }

    return (
      <Form {...formItemLayout} className="verify-form" id="verifycard1">
        <Row gutter={24}>
          <Col span={6}>
            <Form.Item label={'名称'}>
              {getFieldDecorator('label', {
                initialValue: '',
                rules: [
                  {
                    required: true,
                    message: dict['form.required.input'] + '名称!'
                  }
                ]
              })(<Input placeholder="" autoComplete="off" />)}
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item label={'字段'}>
              {getFieldDecorator('field', {
                initialValue: '',
                rules: [
                  {
                    required: true,
                    message: dict['form.required.input'] + '字段!'
                  },
                  {
                    pattern: /^[\u4E00-\u9FA50-9a-zA-Z_]*$/ig,
                    message: '字段名只允许包含数字、字母、汉字以及_'
                  }
                ]
              })(<Input placeholder="" autoComplete="off" />)}
            </Form.Item>
          </Col>
          <Col span={6}>
            <Form.Item label={'数据类型'}>
              {getFieldDecorator('datatype', {
                initialValue: '',
                rules: [
                  {
                    required: true,
                    message: dict['form.required.select'] + '数据类型!'
                  }
                ]
              })(
                <Select>
                  <Select.Option value="Nvarchar(10)"> Nvarchar(10) </Select.Option>
                  <Select.Option value="Nvarchar(20)"> Nvarchar(20) </Select.Option>
                  <Select.Option value="Nvarchar(50)"> Nvarchar(50) </Select.Option>
                  <Select.Option value="Nvarchar(100)"> Nvarchar(100) </Select.Option>
                  <Select.Option value="Nvarchar(512)"> Nvarchar(512) </Select.Option>
                  <Select.Option value="Nvarchar(1024)"> Nvarchar(1024) </Select.Option>
                  <Select.Option value="Nvarchar(2048)"> Nvarchar(2048) </Select.Option>
                  <Select.Option value="Nvarchar(max)"> Nvarchar(max) </Select.Option>
                  <Select.Option value="Int"> Int </Select.Option>
                  <Select.Option value="Decimal(18,0)"> Decimal(18,0) </Select.Option>
                  <Select.Option value="Decimal(18,1)"> Decimal(18,1) </Select.Option>
                  <Select.Option value="Decimal(18,2)"> Decimal(18,2) </Select.Option>
                  <Select.Option value="Decimal(18,3)"> Decimal(18,3) </Select.Option>
                  <Select.Option value="Decimal(18,4)"> Decimal(18,4) </Select.Option>
                  <Select.Option value="Decimal(18,5)"> Decimal(18,5) </Select.Option>
                  <Select.Option value="Decimal(18,6)"> Decimal(18,6) </Select.Option>
                  <Select.Option value="Decimal(18,7)"> Decimal(18,7) </Select.Option>
                  <Select.Option value="Decimal(18,8)"> Decimal(18,8) </Select.Option>
                  <Select.Option value="Decimal(18,9)"> Decimal(18,9) </Select.Option>
                  <Select.Option value="Decimal(18,10)"> Decimal(18,10) </Select.Option>
                  <Select.Option value="Decimal(18,11)"> Decimal(18,11) </Select.Option>
                  <Select.Option value="Decimal(18,12)"> Decimal(18,12) </Select.Option>
                  <Select.Option value="Decimal(18,13)"> Decimal(18,13) </Select.Option>
                  <Select.Option value="Decimal(18,14)"> Decimal(18,14) </Select.Option>
                  <Select.Option value="Decimal(18,15)"> Decimal(18,15) </Select.Option>
                  <Select.Option value="Decimal(18,16)"> Decimal(18,16) </Select.Option>
                  <Select.Option value="Decimal(18,17)"> Decimal(18,17) </Select.Option>
                  <Select.Option value="Decimal(18,18)"> Decimal(18,18) </Select.Option>
                  <Select.Option value="date"> date </Select.Option>
                  <Select.Option value="datetime"> datetime </Select.Option>
                </Select>
              )}
            </Form.Item>
          </Col>
          <Col span={3} className="add">
            <Button onClick={this.handleConfirm} type="primary" className="mk-green">
              {dict['model.add']}
            </Button>
          </Col>
        </Row>
      </Form>
    )
  }
}

export default Form.create()(UniqueForm)